@@ -1,7 +1,7 @@
 """Top-level package for ABC Radio Wrapper."""
 
+__version__ = '0.3.0'
 __author__ = """Matthew Burke"""
-__email__ = 'mperoburke@gmail.com'
-__version__ = '0.2.1'
+__email__ = "mperoburke@gmail.com"
 
 from .abc_radio_wrapper import *  # noqa
